"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

require("core-js/features/array/for-each");

require("core-js/features/array/filter");

require("core-js/features/array/includes");

var _ci = _interopRequireDefault(require("./ci360.service"));

var _ci2 = require("./ci360.utils");

function init() {
  var viewers = [];
  var view360Array = document.querySelectorAll('.cloudimage-360:not(.initialized)');
  var hotspotsConfigs = window.CI360.hotspots || {};
  [].slice.call(view360Array).forEach(function (container) {
    var hotspotInstanceName = (0, _ci2.attr)(container, 'hotspot-instance') || (0, _ci2.attr)(container, 'data-hotspot-instance');
    var hotspotConfig = hotspotsConfigs[hotspotInstanceName] ? hotspotsConfigs[hotspotInstanceName] : null;
    viewers.push(new _ci.default(container, false, hotspotConfig));
  });
  window.CI360._viewers = viewers;
}

function destroy() {
  if (isNoViewers()) return;

  window.CI360._viewers.forEach(function (viewer) {
    viewer.destroy();
  });

  window.CI360._viewers = [];
}

function getActiveIndexByID(id, oriantation) {
  if (isNoViewers()) return;

  var currentViewer = window.CI360._viewers.filter(function (viewer) {
    return viewer.id === id;
  })[0];

  if (oriantation === 'y') {
    return currentViewer && currentViewer.activeImageY - 1;
  }

  return currentViewer && currentViewer.activeImageX - 1;
}

function update() {
  var id = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
  var forceUpdate = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;

  if (id) {
    try {
      var view = window.CI360._viewers.filter(function (viewer) {
        return viewer.id === id;
      })[0];

      return view.updatePlugin(forceUpdate);
    } catch (_unused) {
      console.error("Cloudimage-360: there is no view with such id '".concat(id, "'"));
    }
  }

  return window.CI360._viewers.forEach(function (viewer) {
    viewer.updatePlugin(forceUpdate);
  });
}

function isNoViewers() {
  return !(window.CI360._viewers && window.CI360._viewers.length > 0);
}

window.CI360 = window.CI360 || {};
window.CI360.init = init;
window.CI360.destroy = destroy;
window.CI360.getActiveIndexByID = getActiveIndexByID;
window.CI360.update = update;

if (!window.CI360.notInitOnLoad) {
  init();
}